/*
    Copyright (c) 1996 Matsushita Electric Industrial Co., LTD.
    All rights reserved.
*/
/* This Rexx script will place the correct config.sys statements
   into your config.sys to give you access to the IDE PD drive.
   Your old config.sys will be renamed config.pd. If the script determines
   statements from prior levels of support, those lines will be remarked so
   that they no longer load.

   This script can be run with command line parameters, a response file,
   or the program can ask the user for data it requires if neither a response
   file or command line parameters are supplied.

   Valid command line paramters:

   /R:<response file name>       This parameter specifies the drive, path,
                                 and name of the response file to use.
                                 (If no reponse file is specified, the program
                                 will ask for confirmation on choices before
                                 attempting the install.)

   /L1:<error log file>          These parameters specify the drive, path
   /L2:<History log file>        and names of the log files.

   /S:<source location>          This parameter specifies the source drive
                                 and path.

   /T:<target drive>             This parameter specifies the target drive
                                 for the config.sys updates and file
                                 placement.

   /RK:<keyword=value>           This parameter is used to override any keyword
                                 settings in the response file.
     KEYWORDS:
     target                      target drive for driver (OS/2 boot drive)
     source                      source path for driver files


*/
Signal ON HALT

responsef='NONE'
log.error=''
log.hist=''
source='.'
sourcer='.'
target='\'
targetr='\'
rc_success_reboot = 65024
rc_fail_no_reboot = 64768
version='960807'

Parse Arg args

ret_code = Init_Cmd(args)   /* parse the command line arguments */

if ret_code = 0 then do
   if responsef\=none then do  /* If a response file was specified, read it */
      call readresp
      if source='.' then
         source=sourcer
      if target='\' then
         target=targetr
   end
   else if ret_code = 0 then do  /* If no responsefile, ask for verification */
      say ''
      say 'OS/2 PD driver installation script version 'version
      say ''
      call dumpvals
      say ''
      say 'Press the Enter key if these setting are correct.'
      say 'Press control-c and then the enter key if incorrect,'
      pull key
      call RxFuncAdd 'SysLoadFuncs', 'RexxUtil', 'SysLoadFuncs'
      call SysLoadFuncs
   end
end

if ret_code = 0 then
   ret_code = covertconfig()             /* convert config.sys */

if ret_code = 0 then
   ret_code = copyfiles()                /* copy the driver files */

exit(ret_code)


/*-------------------------------*/
/* Read in command line settings */
/*-------------------------------*/
INIT_CMD: Procedure Expose responsef log.error log.hist source target

Parse Arg args
ret_code = 0

originalargs=args

do while args\=''
   parse value args with trash '/' token args
   PARSE upper value token with key ':' val
   select
      when key = 'R' then
         responsef=val
      when key = 'L1' then
         log.error=val
      when key = 'L2' then
         log.hist=val
      when key = 'S' then
         source=val
      when key = 'T' then
         target=substr(val,1,1)':\'
      when key = 'RK' then do
         parse upper value val with keyword '=' keyval
         if keyword='SOURCE' then
            source=keyval
         if keyword='TARGET' then
            target=keyval
      end
      otherwise
        rc= recerror('->'key'<- is an invalid switch')
        ret_code  = rc_fail_no_reboot
   end /* end select statement */
end

rc=rechist('Started PDINST.CMD with command arguments: 'originalargs)

return ( ret_code )

/*-----------------------------*/
/* Dumps the internal settings */
/*-----------------------------*/
dumpvals: Procedure Expose responsef log.error log.hist source target

if responsef \= 'NONE' then
   say 'the response file is 'responsef
if log.error \= '' then
   say 'the error log is     'log.error
if  log.hist \= '' then
   say 'the history log is   'log.hist

say 'the source dir is    'source
say 'the target drive is  'target

return


/*-----------------------------*/
/* Reads the response file     */
/*-----------------------------*/
readresp: Procedure Expose responsef sourcer targetr log.hist log.error

   do while lines(responsef)
      line=linein(responsef)
      if commentline(line) then do
         iterate
      end
      parse Upper value line with keyword '=' value
      if keyword='SOURCE' then do
         sourcer=value
         rc=rechist('Found keyword SOURCE with value 'value)
      end
      if keyword='TARGET' then do
         targetr=substr(value,1,1)':\'
         rc=rechist('Found keyword TARGET with value 'value)
      end
   end

return

COMMENTLINE: Procedure
   parse arg line
   j=length(line)
   i=0
   do while i < j
      i=i+1
      if substr(line,i,1)='*' then
         return( 1 )
      else if substr(line,i,1)='#' then
         return( 1 )
      else if substr(line,i,1)=' ' then
         iterate
      else if c2d(substr(line,i,1))=8 then
         iterate
      else
         return( 0 )
   end
return ( 1 )

COVERTCONFIG: Procedure expose target log.hist log.error
   s506=yes       /*If we find these, we can leave them */
   os2cdrom=yes
   idecd=yes
   idepd=yes
   optical=yes

   outfile=target'config.sys'
   infile=target'config.pd'
   if stream(outfile, 'C', 'Query Exists') = '' then do
      rc=recerror('Error, could not locate file 'outfile)
      return ( rc_fail_no_reboot ) /* could not open config.sys */
   end

   '@copy 'outfile infile '> nul'

   tempfile=systempfilename(target'config.???');
   rc=rechist('Using temporary file 'tempfile)
   do while lines(infile)
      line=linein(infile)
      parse upper value line with keyword "=" therest
      if (keyword=BASEDEV) then do
         parse upper value therest with name parms
         select
            when name = PIIXIDE.ADD then do
               rc=lineout(tempfile,'REM PD install')
               rc=lineout(tempfile,'REM 'line)
               rc=rechist('REMed config.sys statement for PIIXIDE.ADD')
            end
            when name = PIIXIDE.FLT then do
               rc=lineout(tempfile,'REM PD install')
               rc=lineout(tempfile,'REM 'line)
               rc=rechist('REMed config.sys statement for PIIXIDE.FLT')
            end
            when name = IBM1S506.ADD then do
               s506 = no
               rc=lineout(tempfile, line)
               rc=rechist('Found config.sys statement for IBM1S506.ADD.  No change')
            end
            when name = OS2CDROM.DMD then do
               os2cdrom = no
               rc=lineout(tempfile, line)
               rc=rechist('Found config.sys statement for OS2CDROM.DMD.  No change')
            end
            when name = IBMIDECD.FLT then do
               idecd = no
               rc=lineout(tempfile, line)
               rc=rechist('Found config.sys statement for IBMIDECD.FLT.  No change')
            end
            when name = IBMIDEPD.FLT then do
               idepd = no
               rc=lineout(tempfile, line)
               rc=rechist('Found config.sys statement for IBMIDEPD.FLT.  No change')
            end
            when name = OPTICAL.DMD then do
               optical = no
               rc=lineout(tempfile, line)
               rc=rechist('Found config.sys statement for OPTICAL.DMD.  No change')
            end
            when name = OPTICAL.SYS then do
               rc=lineout(tempfile,'REM PD install')
               rc=lineout(tempfile,'REM 'line)
               rc=rechist('REMed config.sys statement for OPTICAL.SYS')
            end
            otherwise
               rc=lineout(tempfile, line)
         end
      end
      else if (keyword=DEVICE) then do
         if pos(' ',therest) = 0 then
            pathname=therest
         else
            pathname=substr(therest,1,pos(' ',therest))

         lpname=pathname
         do while pos('\',pathname)\=0
            parse UPPER value pathname with apath '\' pathname
         end
         if pathname = OS2CDROM.DMD then do
            os2cdrom = no
            rc=rechist('Found config.sys statement for OS2CDROM.DMD.  No change')
            rc=lineout(tempfile, line)
         end
         else
         if pathname = OPTICAL.DMD then do
            optical = no
            rc=rechist('Found config.sys statement for OPTICAL.DMD.  No change')
            rc=lineout(tempfile, line)
         end
         else
         if pathname = OPTICAL.SYS then do
            rc=lineout(tempfile,'REM PD install')
            rc=lineout(tempfile,'REM 'line)
            rc=rechist('REMed config.sys statement for OPTICAL.SYS')
         end
         else
            rc=lineout(tempfile, line)
      end
      else rc=lineout(tempfile, line)
   end /* while loop for lines in config.pd */

   if s506=yes then do
      rc=lineout(tempfile,'BASEDEV=IBM1S506.ADD')
      rc=rechist('Adding config.sys statement for IBM1S506.ADD.')
   end
   if os2cdrom=yes then do
      rc=lineout(tempfile,'DEVICE='target'os2\boot\os2cdrom.dmd')
      rc=rechist('Adding config.sys statement for OS2CDROM.DMD.')
   end
   if idecd=yes then do
      rc=lineout(tempfile,'BASEDEV=IBMIDECD.FLT')
      rc=rechist('Adding config.sys statement for IBMIDECD.FLT.')
   end
   if idepd=yes then do
      rc=lineout(tempfile,'BASEDEV=IBMIDEPD.FLT')
      rc=rechist('Adding config.sys statement for IBMIDEPD.FLT.')
   end
   if optical=yes then do
      rc=lineout(tempfile,'DEVICE='target'os2\boot\optical.dmd')
      rc=rechist('Adding config.sys statement for OPTICAL.DMD.')
   end

   rc=lineout(tempfile)
   '@copy 'tempfile outfile '> nul'
   rc=sysfiledelete(tempfile)
return ( 0 )

COPYFILES: procedure expose target source log.hist log.error

   file.1.name = 'ibmidecd.flt'
   file.1.dest = 'os2\boot\'
   file.2.name = 'optical.dmd'
   file.2.dest = 'os2\boot\'
   file.3.name = 'ibmidepd.flt'
   file.3.dest = 'os2\boot\'
   file.4.name = 'pdformat.exe'
   file.4.dest = 'os2\'
   file.0 = 4

   targetfile=target''file.1.dest''file.1.name

   if stream(targetfile, 'C', 'query exists') = '' then
      tc=rechist('Original IBMIDECD.FLT was not found.  No backup created.');
   else do
      '@copy 'targetfile target'ibmidecd.os2 > NUL'
      rc=rechist('Copying existing file IBMIDECD.FLT to IBMIDECD.OS2.')
   end

   do i = 1 to file.0
      if stream(source'\'file.i.name, 'C', 'query exists') = '' then do
         rc=recerror('Could not find source file: 'source'\'file.i.name );
         return (rc_fail_no_reboot)
      end
   end

   do i = 1 to file.0
      '@copy 'source'\'file.i.name target''file.i.dest'. > NUL'
       rc=rechist('Copying file 'file.i.name' to 'target''file.i.dest'.')
   end

return(rc_success_reboot)

THEDATE: procedure
   parse value date('n') with dd mon yyyy
   parse value date('e') with day '/' mm '/' year

return (dd'-'mm'-'yyyy left(time('l'),11))

RECERROR: procedure expose log.error
   PARSE ARG themessage
   rc=lineout(log.error,thedate()' 'themessage)
   if log.error \= '' then
      say thedate()' 'themessage
return(0)

RECHIST: procedure expose log.hist
   PARSE ARG themessage
   if log.hist \= '' then
      rc=lineout(log.hist,thedate()' 'themessage)
return(0)


HALT:
  SAY 'Exiting install due to Control-C'
  rc=recerror('Exited program with control-c')
  rc=rechist('Exited program with control-c')
exit (rc_fail_no_reboot)


